==> d1-pac-0.0.19.crate: d1-pac-0.0.19/src/uart/dlh.rs <==
#[doc = "Register `DLH` reader"]
pub struct R(crate::R<DLH_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<DLH_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<DLH_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<DLH_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `DLH` writer"]
pub struct W(crate::W<DLH_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<DLH_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<DLH_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<DLH_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `dlh` reader - "]
pub struct DLH_R(crate::FieldReader<u8>);
impl DLH_R {
    #[inline(always)]
    pub(crate) fn new(bits: u8) -> Self {
        DLH_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for DLH_R {
    type Target = crate::FieldReader<u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `dlh` writer - "]
pub struct DLH_W<'a> {
    w: &'a mut W,
}
impl<'a> DLH_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xff) | (value as u32 & 0xff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:7"]
    #[inline(always)]
    pub fn dlh(&self) -> DLH_R {
        DLH_R::new((self.bits & 0xff) as u8)
    }
}
impl W {
    #[doc = "Bits 0:7"]
    #[inline(always)]
    pub fn dlh(&mut self) -> DLH_W {
        DLH_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "UART Divisor Latch High Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dlh](index.html) module"]
pub struct DLH_SPEC;
impl crate::RegisterSpec for DLH_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [dlh::R](R) reader structure"]
impl crate::Readable for DLH_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [dlh::W](W) writer structure"]
impl crate::Writable for DLH_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets DLH to value 0"]
impl crate::Resettable for DLH_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> d1-pac-0.0.22.crate: d1-pac-0.0.22/src/uart/dlh.rs <==
#[doc = "Register `DLH` reader"]
pub struct R(crate::R<DLH_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<DLH_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<DLH_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<DLH_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `DLH` writer"]
pub struct W(crate::W<DLH_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<DLH_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<DLH_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<DLH_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `dlh` reader - "]
pub type DLH_R = crate::FieldReader<u8, u8>;
#[doc = "Field `dlh` writer - "]
pub type DLH_W<'a> = crate::FieldWriter<'a, u32, DLH_SPEC, u8, u8, 8, 0>;
impl R {
    #[doc = "Bits 0:7"]
    #[inline(always)]
    pub fn dlh(&self) -> DLH_R {
        DLH_R::new((self.bits & 0xff) as u8)
    }
}
impl W {
    #[doc = "Bits 0:7"]
    #[inline(always)]
    pub fn dlh(&mut self) -> DLH_W {
        DLH_W::new(self)
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "UART Divisor Latch High Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dlh](index.html) module"]
pub struct DLH_SPEC;
impl crate::RegisterSpec for DLH_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [dlh::R](R) reader structure"]
impl crate::Readable for DLH_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [dlh::W](W) writer structure"]
impl crate::Writable for DLH_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets DLH to value 0"]
impl crate::Resettable for DLH_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
